# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKQuadEdgeMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkQuadEdgeCellTraitsInfoPython
else:
    import _itkQuadEdgeCellTraitsInfoPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkQuadEdgeMeshPointPython
import itk.itkGeometricalQuadEdgePython
import itk.itkQuadEdgePython

def itkMapContainerULQEMPF2GQEULULBBT_New():
    return itkMapContainerULQEMPF2GQEULULBBT.New()

class itkMapContainerULQEMPF2GQEULULBBT(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMapContainerULQEMPF2GQEULULBBT class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkMapContainerULQEMPF2GQEULULBBT
        __init__(self, comp) -> itkMapContainerULQEMPF2GQEULULBBT

        Parameters
        ----------
        comp: std::less< unsigned long > const &

        """
        _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_swiginit(self, _itkQuadEdgeCellTraitsInfoPython.new_itkMapContainerULQEMPF2GQEULULBBT(*args))

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMapContainerULQEMPF2GQEULULBBT_Pointer"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMapContainerULQEMPF2GQEULULBBT_Pointer"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::map< unsigned long,itkQuadEdgeMeshPointF2GQEULULBBT,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkQuadEdgeMeshPointF2GQEULULBBT > > > &"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::map< unsigned long,itkQuadEdgeMeshPointF2GQEULULBBT,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkQuadEdgeMeshPointF2GQEULULBBT > > > const &"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkQuadEdgeMeshPointF2GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkQuadEdgeMeshPointF2GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkQuadEdgeMeshPointF2GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkQuadEdgeMeshPointF2GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF2GQEULULBBT

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF2GQEULULBBT

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF2GQEULULBBT *

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_Initialize(self)
    __swig_destroy__ = _itkQuadEdgeCellTraitsInfoPython.delete_itkMapContainerULQEMPF2GQEULULBBT

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMapContainerULQEMPF2GQEULULBBT

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMapContainerULQEMPF2GQEULULBBT

        Create a new object of the class itkMapContainerULQEMPF2GQEULULBBT and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMapContainerULQEMPF2GQEULULBBT.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMapContainerULQEMPF2GQEULULBBT.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMapContainerULQEMPF2GQEULULBBT.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMapContainerULQEMPF2GQEULULBBT in _itkQuadEdgeCellTraitsInfoPython:
_itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF2GQEULULBBT_swigregister(itkMapContainerULQEMPF2GQEULULBBT)

def itkMapContainerULQEMPF3GQEULULBBT_New():
    return itkMapContainerULQEMPF3GQEULULBBT.New()

class itkMapContainerULQEMPF3GQEULULBBT(itk.ITKCommonBasePython.itkObject):
    r"""Proxy of C++ itkMapContainerULQEMPF3GQEULULBBT class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkMapContainerULQEMPF3GQEULULBBT
        __init__(self, comp) -> itkMapContainerULQEMPF3GQEULULBBT

        Parameters
        ----------
        comp: std::less< unsigned long > const &

        """
        _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_swiginit(self, _itkQuadEdgeCellTraitsInfoPython.new_itkMapContainerULQEMPF3GQEULULBBT(*args))

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMapContainerULQEMPF3GQEULULBBT_Pointer"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMapContainerULQEMPF3GQEULULBBT_Pointer"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_Clone(self)

    def CastToSTLContainer(self):
        r"""CastToSTLContainer(self) -> std::map< unsigned long,itkQuadEdgeMeshPointF3GQEULULBBT,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkQuadEdgeMeshPointF3GQEULULBBT > > > &"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_CastToSTLContainer(self)

    def CastToSTLConstContainer(self):
        r"""CastToSTLConstContainer(self) -> std::map< unsigned long,itkQuadEdgeMeshPointF3GQEULULBBT,std::less< unsigned long >,std::allocator< std::pair< unsigned long const,itkQuadEdgeMeshPointF3GQEULULBBT > > > const &"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_CastToSTLConstContainer(self)

    def ElementAt(self, *args):
        r"""
        ElementAt(self, arg0) -> itkQuadEdgeMeshPointF3GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        ElementAt(self, arg0) -> itkQuadEdgeMeshPointF3GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_ElementAt(self, *args)

    def CreateElementAt(self, arg0):
        r"""
        CreateElementAt(self, arg0) -> itkQuadEdgeMeshPointF3GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_CreateElementAt(self, arg0)

    def GetElement(self, arg0):
        r"""
        GetElement(self, arg0) -> itkQuadEdgeMeshPointF3GQEULULBBT

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_GetElement(self, arg0)

    def SetElement(self, arg0, arg1):
        r"""
        SetElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF3GQEULULBBT

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_SetElement(self, arg0, arg1)

    def InsertElement(self, arg0, arg1):
        r"""
        InsertElement(self, arg0, arg1)

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF3GQEULULBBT

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_InsertElement(self, arg0, arg1)

    def IndexExists(self, arg0):
        r"""
        IndexExists(self, arg0) -> bool

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_IndexExists(self, arg0)

    def GetElementIfIndexExists(self, arg0, arg1):
        r"""
        GetElementIfIndexExists(self, arg0, arg1) -> bool

        Parameters
        ----------
        arg0: unsigned long
        arg1: itkQuadEdgeMeshPointF3GQEULULBBT *

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_GetElementIfIndexExists(self, arg0, arg1)

    def CreateIndex(self, arg0):
        r"""
        CreateIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_CreateIndex(self, arg0)

    def DeleteIndex(self, arg0):
        r"""
        DeleteIndex(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_DeleteIndex(self, arg0)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_Size(self)

    def Reserve(self, arg0):
        r"""
        Reserve(self, arg0)

        Parameters
        ----------
        arg0: unsigned long

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_Reserve(self, arg0)

    def Squeeze(self):
        r"""Squeeze(self)"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_Squeeze(self)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_Initialize(self)
    __swig_destroy__ = _itkQuadEdgeCellTraitsInfoPython.delete_itkMapContainerULQEMPF3GQEULULBBT

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMapContainerULQEMPF3GQEULULBBT

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMapContainerULQEMPF3GQEULULBBT

        Create a new object of the class itkMapContainerULQEMPF3GQEULULBBT and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMapContainerULQEMPF3GQEULULBBT.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMapContainerULQEMPF3GQEULULBBT.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMapContainerULQEMPF3GQEULULBBT.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMapContainerULQEMPF3GQEULULBBT in _itkQuadEdgeCellTraitsInfoPython:
_itkQuadEdgeCellTraitsInfoPython.itkMapContainerULQEMPF3GQEULULBBT_swigregister(itkMapContainerULQEMPF3GQEULULBBT)
class itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE(object):
    r"""Proxy of C++ itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE
        __init__(self, arg0) -> itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE

        Parameters
        ----------
        arg0: itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE const &

        """
        _itkQuadEdgeCellTraitsInfoPython.itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE_swiginit(self, _itkQuadEdgeCellTraitsInfoPython.new_itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE(*args))
    __swig_destroy__ = _itkQuadEdgeCellTraitsInfoPython.delete_itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE

# Register itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE in _itkQuadEdgeCellTraitsInfoPython:
_itkQuadEdgeCellTraitsInfoPython.itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE_swigregister(itkQuadEdgeMeshCellTraitsInfo2FFULULUCQEMPGQEULQEMPF2GQEULULBBTGQE)
class itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE(object):
    r"""Proxy of C++ itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(self) -> itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE
        __init__(self, arg0) -> itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE

        Parameters
        ----------
        arg0: itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE const &

        """
        _itkQuadEdgeCellTraitsInfoPython.itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE_swiginit(self, _itkQuadEdgeCellTraitsInfoPython.new_itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE(*args))
    __swig_destroy__ = _itkQuadEdgeCellTraitsInfoPython.delete_itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE

# Register itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE in _itkQuadEdgeCellTraitsInfoPython:
_itkQuadEdgeCellTraitsInfoPython.itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE_swigregister(itkQuadEdgeMeshCellTraitsInfo3FFULULUCQEMPGQEULQEMPF3GQEULULBBTGQE)

